@@ -3,13 +3,21 @@
 
 # imports.
 from r3sponse.v1.classes.config import *
+from r3sponse.v1.classes import utils
 from django.http import JsonResponse
 
 # the manager class.
 class R3sponse(object):
 	def __init__(self):	
+
+		# set log file.
 		self.log_file = None
-		self.log_level = -1
+
+		# set log level.
+		self.log_level = 0
+		if utils.argument_present('--log-level'):
+			try: self.log_level = int(utils.get_argument('--log-level'))
+			except: self.log_level = 0
 		#
 
 	# response functions.
@@ -93,7 +101,6 @@ class R3sponse(object):
 			if response["error"] != None: return response
 		return response
 
-
 	# log functions.
 	def load_logs(self, format="webserver", options=["webserver", "cli", "array", "string"]):
 		try:
